@@ -4,10 +4,6 @@ library(knitr)
 
 ## ---- echo=FALSE--------------------------------------------------------------
 kable(
-  dplyr::arrange(
-    rgho:::to_data_frame(
-      get_gho_codes(dimension = "COUNTRY")
-      ),
-    Label)
+      get_gho_values(dimension = "COUNTRY")
   )
 
